@@ -50,6 +50,9 @@ package Debian::Control;
 
 use base 'Class::Accessor';
 use strict;
+use warnings;
+
+our $VERSION = '0.77';
 
 __PACKAGE__->mk_accessors(qw( source binary binary_tie _parser ));
 
